@@ -9,8 +9,8 @@ import copy
 import json
 import os
 import random
-import time
 import subprocess
+import time
 
 import _damo_fmt_str
 import damo_version
@@ -627,40 +627,34 @@ class DamosWatermarks:
                 ])
 
 class DamosFilter:
-    filter_type = None  # anon, memcg, young, addr, or target
+    filter_type = None  # anon, memcg, young, hugepage, addr, or target
     matching = None
-    filter_pass = None
+    allow = None
     memcg_path = None
     address_range = None    # DamonRegion
     damon_target_idx = None
     scheme = None
 
-    def __init__(self, filter_type, matching, filter_pass=False,
+    def __init__(self, filter_type, matching, allow=False,
                  memcg_path=None, address_range=None, damon_target_idx=None):
         self.filter_type = filter_type
         self.matching = _damo_fmt_str.text_to_bool(matching)
         self.memcg_path = memcg_path
-        self.filter_pass = _damo_fmt_str.text_to_bool(filter_pass)
+        self.allow = _damo_fmt_str.text_to_bool(allow)
         self.address_range = address_range
         if damon_target_idx != None:
             self.damon_target_idx = _damo_fmt_str.text_to_nr(damon_target_idx)
 
     def to_str(self, raw):
-        type_to_text = {
-                'anon': ['anon pages', 'file-backed pages'],
-                'memcg': ['pages in memcg', 'pages not in memcg'],
-                'young': ['young pages', 'old pages'],
-                'addr': ['memory in addr', 'memory not in addr'],
-                'target': ['memory in target', 'memory not in target']
-                }
         words = []
-        if self.filter_pass:
-            words.append('pass')
+        if self.allow:
+            words.append('allow')
         else:
-            words.append('block')
-        match_idx = 0 if self.matching is True else 1
-        words.append(type_to_text[self.filter_type][match_idx])
-        if self.filter_type in ['anon', 'young']:
+            words.append('reject')
+        if self.matching is False:
+            words.append('none')
+        words.append(self.filter_type)
+        if self.filter_type in ['anon', 'young', 'hugepage']:
             return ' '.join(words)
         if self.filter_type == 'memcg':
             return ' '.join(words + [self.memcg_path])
@@ -678,9 +672,15 @@ class DamosFilter:
 
     @classmethod
     def from_kvpairs(cls, kv):
+        allow = False
+        if 'allow' in kv:
+            allow = kv['allow']
+        # filter_pass has renamed to allow
+        elif 'filter_pass' in kv:
+            allow = kv['filter_pass']
         return DamosFilter(
                 kv['filter_type'], kv['matching'],
-                kv['filter_pass'] if 'filter_pass' in kv else False,
+                allow,
                 kv['memcg_path'] if kv['filter_type'] == 'memcg' else '',
                 DamonRegion.from_kvpairs(kv['address_range'])
                     if kv['filter_type'] == 'addr' else None,
@@ -691,7 +691,7 @@ class DamosFilter:
         return collections.OrderedDict([
             ('filter_type', self.filter_type),
             ('matching', self.matching),
-            ('filter_pass', self.filter_pass),
+            ('allow', self.allow),
             ('memcg_path', self.memcg_path),
             ('address_range', self.address_range.to_kvpairs(raw) if
                 self.address_range != None else None),
@@ -701,7 +701,7 @@ class DamosFilter:
 
     def handled_by_ops(self):
         # whether this filter is handled by DAMON operations set layer
-        return self.filter_type in ['anon', 'memcg', 'young']
+        return self.filter_type in ['anon', 'memcg', 'young', 'hugepage']
 
 class DamosStats:
     nr_tried = None
@@ -1015,7 +1015,7 @@ class Kdamond:
 
     def __hash__(self):
         return hash(self.__str__())
-    
+
     def get_cpu_usage(self):
         if self.state == "off":
             return "0.0"
@@ -1097,7 +1097,9 @@ features = ['record',       # was in DAMON patchset, but not merged in mainline
             'schemes_filters_young',    # merged in v6.10-rc1
             'schemes_migrate',          # merged in v6.11-rc1
             'sz_ops_filter_passed',     # developing
-            'pass_filter',              # developing
+            'pass_filter',              # was developing, renamed to
+                                        # pass_filter after v1 patch
+            'allow_filter',             # developing
             ]
 
 _damon_fs = None
@@ -1241,7 +1243,7 @@ def initialize(damon_interface, debug_damon, is_stop):
     if is_stop:
         return None
 
-    # While DAMON is running, feature chekcing I/O can fail, corrupt something,
+    # While DAMON is running, feature checking I/O can fail, corrupt something,
     # or make something complicated.
     if any_kdamond_running():
         return 'feature_supports loading failed (%s), and DAMON is running'
